@@ -1,5 +1,5 @@
 package Photonic::Types;
-$Photonic::Types::VERSION = '0.022';
+$Photonic::Types::VERSION = '0.023';
 
 =encoding UTF-8
 
@@ -51,7 +51,7 @@ declare GeometryG0 =>
 
 declare Haydock =>
   as ConsumerOf['Photonic::Roles::Haydock'],
-  message { "Expected an AllH" };
+  message { "Expected a Haydock" };
 
 declare HaydockSave =>
   as Haydock,
@@ -67,6 +67,16 @@ declare PDLComplex =>
   where { any_complex($_) },
   ;
 
+declare PDLComplexMatrix =>
+  as PDLComplex,
+  where { $_->ndims>=2 && $_->dim(0)==$_->dim(1)},
+  ;
+
+declare PDLComplexMatrixField => # NxN matrix for each point in N dimensional space
+  as PDLComplexMatrix,
+  where { $_->dim(0)==$_->ndims-2},
+  ;
+
 __END__
 
 =head1 NAME
@@ -75,7 +85,7 @@ Photonic::Types
 
 =head1 VERSION
 
-version 0.008
+version 0.023
 
 =head1 SYNOPSIS
 
